from db.models import Book
from web.forms import ModelForm


class AlertForm(ModelForm):
    class Meta:
        model = Book
        fields = [
            "title",
            "isbn",
            "published_at",
            "author",
            "license",
            "visible"
        ]



# Generated by Django 3.0.5 on 2020-06-07 10:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('db', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='visibility',
            field=models.BooleanField(default=False, help_text='Give the visibility status of the post', verbose_name='visibility'),
        ),
        migrations.AlterField(
            model_name='post',
            name='title',
            field=models.CharField(help_text='Title of post', max_length=255, verbose_name='title'),
        ),
    ]



# Create your tests here.
import unittest

from precise_bbcode.bbcode import get_parser

"""
    BBCode tests
"""


class TestBBCodes(unittest.TestCase):
    tests = {
        "invisible": {
            "source_text": "blabla[invisible]blabla[/invisible]blabla",
            "target_text": "blabla<span style:\"display:none\">blabla</span>blabla",
        },
        "justifier": {
            "source_text": "blabla[justifier]blabla[/justifier]blabla",
            "target_text": "blabla<p style=\"text-align:justify\">blabla</p>blabla",
        },
        "preformatted": {
            "source_text": "blabla[preformatted]blabla[/preformatted]blabla",
            "target_text": "blabla<pre>blabla</pre>blabla",
        },
        "right": {
            "source_text": "blabla[right]blabla[/right]blabla",
            "target_text": "blabla<div align=\"right\">blabla</div>blabla",
        },
    }

    parser = get_parser()

    def test_invisible(self):
        """ test BBCode invisible """
        bbcode_name = "invisible"
        re = self.tests.get(bbcode_name)
        self.assertEqual(
            first=self.parser.render(re.get("source_text")),
            second=re.get("source_text"),
            msg=f"Error on rendering tag '{bbcode_name}'"
        )

    def test_right(self):
        """ test BBCode right """
        bbcode_name = "right"
        re = self.tests.get(bbcode_name)
        self.assertEqual(
            first=self.parser.render(re.get("source_text")),
            second=re.get("source_text"),
            msg=f"Error on rendering tag '{bbcode_name}'"
        )

    def test_justifier(self):
        """ test BBCode justifier """
        bbcode_name = "justifier"
        re = self.tests.get(bbcode_name)
        self.assertEqual(
            first=self.parser.render(re.get("source_text")),
            second=re.get("source_text"),
            msg=f"Error on rendering tag '{bbcode_name}'"
        )

    def test_preformatted(self):
        """ test BBCode preformatted """
        bbcode_name = "preformatted"
        re = self.tests.get(bbcode_name)
        self.assertEqual(
            first=self.parser.render(re.get("source_text")),
            second=re.get("source_text"),
            msg=f"Error on rendering tag '{bbcode_name}'"
        )


if __name__ == '__main__':
    unittest.main()



from db.models import Member
from web.forms import ModelForm


class MemberForm(ModelForm):
    class Meta:
        model = Member
        fields = [
            "username",
            "first_name",
            "last_name",
            "email",
            "date_of_birth",
            "is_active"
        ]



from django import forms
from django.utils.translation import gettext_lazy as _

from web.forms import Form
from web.forms.widgets import TextInput, PasswordInput, SelectDateWidget, EmailInput, CheckboxInput


class RegisterForm(Form):
    login_name = forms.CharField(
        max_length=30,
        widget=TextInput(
            attrs={'placeholder': _('Username')}),
        label=_('Username'))
    email = forms.EmailField(
        max_length=100,
        widget=EmailInput(
            attrs={'placeholder': _('Email')}),
        label=_('Email'))
    password = forms.CharField(
        max_length=30,
        widget=PasswordInput(
            attrs={'placeholder': _('Password')}),
        label=_('Password'))
    passwordRepeat = forms.CharField(
        max_length=30,
        widget=PasswordInput(
            attrs={'placeholder': _('Repeat your password')}),
        label=_('Repeat your password'))
    birth_date = forms.DateField(
        widget=SelectDateWidget(
            attrs={'placeholder': _('Birth date')}),
        label=_('Birth date'))
    cgu_accept = forms.BooleanField(
        required=True,
        widget=CheckboxInput(),
        label=_('I have read and accept the CGU')
    )

    def register(self):
        pass



from precise_bbcode.bbcode import get_parser

from precise_bbcode.bbcode.tag import BBCodeTag
from precise_bbcode.tag_pool import tag_pool


class InvisibleBBCodeTag(BBCodeTag):

    def render(self, value, option=None, parent=None):
        return BBCodeTag.render(value, option, parent)

    name = 'invisible'
    definition_string = '[invisible]{TEXT}[/invisible]'
    format_string = '<span style:"display:none">{TEXT}</span>'

    class Options:
        render_embedded = False
        strip = False


tag_pool.register_tag(InvisibleBBCodeTag)


class RightBBCodeTag(BBCodeTag):

    def render(self, value, option=None, parent=None):
        return BBCodeTag.render(value, option, parent)

    name = 'right'
    definition_string = '[right]{TEXT}[/right]'
    format_string = '<div align="right">{TEXT}</div>'

    class Options:
        render_embedded = False
        strip = False


tag_pool.register_tag(RightBBCodeTag)


class JustifierBBCodeTag(BBCodeTag):

    def render(self, value, option=None, parent=None):
        return BBCodeTag.render(value, option, parent)

    name = 'justify'
    definition_string = '[justifier]{TEXT}[/justifier]'
    format_string = '<p style="text-align:justify">{TEXT}</p>'

    class Options:
        render_embedded = False
        strip = False


tag_pool.register_tag(JustifierBBCodeTag)


class PreFormattedBBCodeTag(BBCodeTag):
    def render(self, value, option=None, parent=None):
        return BBCodeTag.render(value, option, parent)

    name = 'preformatted'
    definition_string = '[pre]{TEXT}[/pre]'
    format_string = '<pre>{TEXT}</pre>'

    class Options:
        render_embedded = False
        strip = False


tag_pool.register_tag(PreFormattedBBCodeTag)


def bbcode2html(text: str):
    parser = get_parser()
    return parser.render(text)
